
#include "RTClib.h"
RTC_DS3231 rtc;

int buttonState = 0;         // variable for reading the pushbutton status
const int buttonPin = 2;     // the number of the pushbutton pin
char days[7][10] = {"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"};
const int ledPin =  13;
int RELAY = 12;

int strike_hours[10] = {9, 10, 11, 12, 13, 14, 15, 16, 17, 18};
int strikes = 0;
int counter = 0;


////////////////////////////---------------------------\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
//////////////////////////// SUBROUTINE TO STRIKE BELL \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
////////////////////////////---------------------------\\\\\\\\\\\\\\\\\\\\\\\\\\\\\

void strike_bell() {                            // Will strike the hour at the 00 min mark, and 00 second mark
  strikes = 0;
  DateTime now = rtc.now();                     //required by rtc library to set now hour/min/second
  strikes = strikes + now.hour();               //sets "strikes" variable to equal hour
  if (now.hour() >= 13) {                       // how to deals with afternoon hours. since this is based on 24 clock,
    strikes = strikes - 12; //deals with afternoon hours.
  }
  
  for (int y = 0; y < strikes; y++) {            // for example if it is 9:00:00, bell will strike 9 times
    digitalWrite(ledPin, HIGH);  // if it is 17:00:00 (5:00 pm), bell will strike 5 times
    digitalWrite(RELAY, LOW);  // turn the buzzer on (HIGH is the voltage level)
    delay(100);                                  // change this delay if needed 
    digitalWrite(ledPin, LOW);
    digitalWrite(RELAY, HIGH);  // turn the buzzer OFF (LOW is the voltage level)
    delay(2000);                                 // change this delay if needed
  }
}

////////////////////////////---------------------------\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
//////////////////////////// SUBROUTINE TO DISPLAY TIME \\\\\\\\\\\\\\\\\\\\\\\\\\\\\
////////////////////////////---------------------------\\\\\\\\\\\\\\\\\\\\\\\\\\\\\

void display_time() {
  DateTime now = rtc.now();
  Serial.print(now.year(), DEC);
  Serial.print('/');
  Serial.print(now.month(), DEC);
  Serial.print('/');
  Serial.print(now.day(), DEC);
  Serial.print(" (");
  Serial.print(days[now.dayOfTheWeek()]);
  Serial.print(") ");
  Serial.print(now.hour(), DEC);
  Serial.print(':');
  Serial.print(now.minute(), DEC);
  Serial.print(':');
  Serial.print(now.second(), DEC);
  Serial.println();
  Serial.print("Temperature: ");
  Serial.print(rtc.getTemperature());
  Serial.println(" C");
  Serial.println();
  delay(1);
  counter = 0;
}



void setup () {
  Serial.begin(9600);
  rtc.begin();
  pinMode(ledPin, OUTPUT);               // Initialize the LED_BUILTIN pin as an output
  pinMode(buttonPin, INPUT);              // initialize the pushbutton pin as an input
  pinMode(RELAY, OUTPUT);
  digitalWrite(RELAY, HIGH);
  //rtc.adjust(DateTime(2020, 02, 20, 19, 38, 00));  // use to set the time.  ONLY use once, then comment out.
}


void loop () {

  counter = counter + 1;  // use counter here to print to serial monitor at a controlled rate
  DateTime now = rtc.now();  //required by clock library to set "now" hour/min/second

  for (int x = 0; x < 10; x++) {
    if (now.hour() == strike_hours[x] && now.minute() == 00 && now.second() == 00) {
      strike_bell();   // strike the bell
      delay(1);
    } else {
      digitalWrite(ledPin, LOW);  // keep LED off:
      digitalWrite(RELAY, HIGH);  // keep LED off:
    }
  }

  if (counter == 4545) { // about every 10 seconds, print time to serial monitor
    display_time();
  }

  buttonState = digitalRead(buttonPin); //if button is pushed, strike bell one time
  if (buttonState == HIGH) {
    digitalWrite(ledPin, HIGH);
    digitalWrite(RELAY, LOW);  // turn the buzzer on (HIGH is the voltage level)
    delay(100);
    digitalWrite(ledPin, LOW);
    digitalWrite(RELAY, HIGH);  // turn the buzzer OFF (LOW is the voltage level)
    delay(1000);
  } else {
    digitalWrite(ledPin, LOW); // keep LED low
    digitalWrite(RELAY, HIGH);  // keep relay OFF (LOW is the voltage level)
    delay(1);
  }



}
